
# Subset: owl


Set of slots that appear in the OWL representation of a model

URI: [linkml:owl](https://w3id.org/linkml/owl)


### Classes


### Mixins


### Slots

 * [comments](comments.md) - notes and comments about an element intended for external consumption
 * [description](description.md) - a description of the element's purpose and use
 * [examples](examples.md) - example usages of an element
 * [generation_date](generation_date.md) - date and time that the schema was loaded/generated
 * [license](license.md) - license for the schema
 * [metamodel_version](metamodel_version.md) - Version of the metamodel used to load the schema
 * [name](name.md) - the unique name of the element within the context of the schema.  Name is combined with the default prefix to form the globally unique subject of the target class.
 * [notes](notes.md) - editorial notes about an element intended for internal consumption
 * [schema_definition➞name](schema_definition_name.md)
 * [see_also](see_also.md) - a reference
 * [source_file](source_file.md) - name, uri or description of the source of the schema
 * [source_file_date](source_file_date.md) - modification date of the source of the schema
 * [source_file_size](source_file_size.md) - size in bytes of the source of the schema
 * [title](title.md) - the official title of the element
 * [version](version.md) - particular version of schema

### Types


### Enums

